# Ocyan plugin Wagtail content page


## Installation
-------------
Add `ocyan.plugin.wagtail_content_page` to your projects dependencies.

 
## Usage
-------------
This plugin comes with a wagtail page model that can be used to generate content pages and makes use of wagtail’s default streamfield editor instead of our roadrunner editor. You can disable certain blocks too, if you’d like. See “Configuration” for more information on this.

## Configuration
Settings you need to configure in .json
* heading
    * Enable/disable heading streamfield
    * Default is true.
* paragraph
    * Enable/disable paragraph streamfield
    * Default is true.
* image
    * Enable/disable image streamfield
    * Default is true.
* table
    * Enable/disable html table
    * Default is true.
* add_to_cart
    * Enable/disable add to cart table
    * Default is false.
* actionbuttons
    * Enable/disable call to action buttons streamfield.
    * Default is false.
* html
    * Enable/disable raw html streamfield
    * Default is false.

Example: 

```json
    "wagtail content page": {
      "heading": false,
      "paragraph": false,
      "image": false,
      "html": true,
    },
```